@@ -244,7 +244,7 @@ class DUMPWriter(StructureWriter):
         ----------
         fname : str
         atoms : `Atoms`
-            An :py:class:`~pksci.chemistry.Atoms` instance.
+            An :py:class:`Atoms` instance.
         boxbounds : dict, optional
             If ``None``, determined automatically from atom coordinates.
         comment_line : str, optional
